AutomaticActivityDetection class

Automatic voice activity detection settings for realtime audio.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

AutomaticActivityDetection({bool? disabled, StartSensitivity? startOfSpeechSensitivity, EndSensitivity? endOfSpeechSensitivity, int? prefixPaddingMs, int? silenceDurationMs})
AutomaticActivityDetection.fromJson(Map<String, dynamic> json)
factory

Properties

disabled bool?
final
endOfSpeechSensitivity EndSensitivity?
final
hashCode int
The hash code for this object.
no setterinherited
prefixPaddingMs int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silenceDurationMs int?
final
startOfSpeechSensitivity StartSensitivity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited