AvatarConfig class

Avatar options for live video-capable sessions.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

AvatarConfig({String? avatarName, CustomizedAvatar? customizedAvatar, int? audioBitrateBps, int? videoBitrateBps})
AvatarConfig.fromJson(Map<String, dynamic> json)
factory

Properties

audioBitrateBps int?
final
avatarName String?
final
customizedAvatar CustomizedAvatar?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoBitrateBps int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited