FunctionResponse class

A tool result sent back to the model.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

FunctionResponse({String? id, String? name, Map<String, dynamic>? response, bool? willContinue, FunctionResponseScheduling? scheduling, List<FunctionResponsePart>? parts})
FunctionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String?
final
parts List<FunctionResponsePart>?
final
response Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduling FunctionResponseScheduling?
final
willContinue bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited