FunctionResponseBlob class

Inline binary data returned from a function response.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

FunctionResponseBlob({String? mimeType, String? data, String? displayName})
FunctionResponseBlob.fromJson(Map<String, dynamic> json)
factory

Properties

data String?
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited