GoogleMaps class
Configuration options for Google Maps grounding in Tool.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)
Constructors
-
GoogleMaps({List<
String> ? groundingTypes}) -
GoogleMaps.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
groundingTypes
→ List<
String> ? -
Grounding types supported by Google Maps, e.g. "places", "routing".
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited