LiveClientSetup class

The initial setup message sent when opening a Live API session.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

LiveClientSetup({required String model, GenerationConfig? generationConfig, Content? systemInstruction, List<Tool>? tools, RealtimeInputConfig? realtimeInputConfig, SessionResumptionConfig? sessionResumption, ContextWindowCompressionConfig? contextWindowCompression, AudioTranscriptionConfig? inputAudioTranscription, AudioTranscriptionConfig? outputAudioTranscription, ProactivityConfig? proactivity, bool? explicitVadSignal, AvatarConfig? avatarConfig, List<SafetySetting>? safetySettings, HistoryConfig? historyConfig})
LiveClientSetup.fromJson(Map<String, dynamic> json)
factory

Properties

avatarConfig → AvatarConfig?
final
contextWindowCompression → ContextWindowCompressionConfig?
final
explicitVadSignal → bool?
final
generationConfig → GenerationConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
historyConfig → HistoryConfig?
Configures the exchange of history between the client and the server.
final
inputAudioTranscription → AudioTranscriptionConfig?
final
model → String
final
outputAudioTranscription → AudioTranscriptionConfig?
final
proactivity → ProactivityConfig?
final
realtimeInputConfig → RealtimeInputConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetySettings → List<SafetySetting>?
final
sessionResumption → SessionResumptionConfig?
final
systemInstruction → Content?
final
tools → List<Tool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited