LiveServerSessionResumptionUpdate class

A session resumption token update from the server.

Annotations
  • @JsonSerializable.new(includeIfNull: false, createToJson: false)

Constructors

LiveServerSessionResumptionUpdate({String? newHandle, bool? resumable, String? lastConsumedClientMessageIndex})
LiveServerSessionResumptionUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastConsumedClientMessageIndex → String?
final
newHandle → String?
final
resumable → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited