RealtimeInputConfig class

Realtime input settings sent during session setup.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

RealtimeInputConfig({AutomaticActivityDetection? automaticActivityDetection, ActivityHandling? activityHandling, TurnCoverage? turnCoverage})
RealtimeInputConfig.fromJson(Map<String, dynamic> json)
factory

Properties

activityHandling ActivityHandling?
final
automaticActivityDetection AutomaticActivityDetection?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnCoverage TurnCoverage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited