SafetySetting class

Safety settings to block unsafe content in Gemini responses.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

SafetySetting({HarmCategory? category, HarmBlockMethod? method, HarmBlockThreshold? threshold})
SafetySetting.fromJson(Map<String, dynamic> json)
factory

Properties

category HarmCategory?
final
hashCode int
The hash code for this object.
no setterinherited
method HarmBlockMethod?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold HarmBlockThreshold?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited