ThinkingConfig class

Thinking controls for models that can emit thought content.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

ThinkingConfig({bool? includeThoughts, int? thinkingBudget, ThinkingLevel? thinkingLevel})
ThinkingConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
includeThoughts bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thinkingBudget int?
final
thinkingLevel ThinkingLevel?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited