GenerationConfig class
Generation parameters used when starting a Live API session.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)
Constructors
-
GenerationConfig({double? temperature, int? topK, double? topP, int? maxOutputTokens, List<
Modality> ? responseModalities, MediaResolution? mediaResolution, int? seed, SpeechConfig? speechConfig, ThinkingConfig? thinkingConfig, bool? enableAffectiveDialog, TranslationConfig? translationConfig, AudioTranscriptionConfig? audioTranscriptionConfig}) -
GenerationConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- audioTranscriptionConfig → AudioTranscriptionConfig?
-
final
- enableAffectiveDialog → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxOutputTokens → int?
-
final
- mediaResolution → MediaResolution?
-
final
-
responseModalities
→ List<
Modality> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → int?
-
final
- speechConfig → SpeechConfig?
-
final
- streamTranslationConfig → TranslationConfig?
-
Deprecated alias for translationConfig.
no setter
- temperature → double?
-
final
- thinkingConfig → ThinkingConfig?
-
final
- topK → int?
-
final
- topP → double?
-
final
- translationConfig → TranslationConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited