LiveClientRealtimeInput class
Realtime media or text input sent while a session is active.
Constructors
-
LiveClientRealtimeInput({List<
Blob> ? mediaChunks, Blob? audio, Blob? video, bool? audioStreamEnd, String? text, ActivityStart? activityStart, ActivityEnd? activityEnd}) -
LiveClientRealtimeInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityEnd → ActivityEnd?
-
final
- activityStart → ActivityStart?
-
final
- audio → Blob?
-
final
- audioStreamEnd → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mediaChunks
→ List<
Blob> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- video → Blob?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited