Part class
A single multimodal part within a content turn.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
Part({PartMediaResolution? mediaResolution, String? text, bool? thought, String? thoughtSignature, Blob? inlineData, FileData? fileData, VideoMetadata? videoMetadata, FunctionCall? functionCall, FunctionResponse? functionResponse, ToolCall? toolCall, ToolResponse? toolResponse, Map<
String, dynamic> ? partMetadata, ExecutableCode? executableCode, CodeExecutionResult? codeExecutionResult}) -
Part.fromJson(Map<
String, dynamic> json) -
factory
Properties
- codeExecutionResult → CodeExecutionResult?
-
final
- executableCode → ExecutableCode?
-
final
- fileData → FileData?
-
final
- functionCall → FunctionCall?
-
final
- functionResponse → FunctionResponse?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineData → Blob?
-
final
- mediaResolution → PartMediaResolution?
-
final
-
partMetadata
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- thought → bool?
-
final
- thoughtSignature → String?
-
final
- toolCall → ToolCall?
-
final
- toolResponse → ToolResponse?
-
final
- videoMetadata → VideoMetadata?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited