ReplicatedVoiceConfig class
Voice cloning settings for custom speech output.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)
Constructors
- ReplicatedVoiceConfig({String? mimeType, String? voiceSampleAudio, String? consentAudio, VoiceConsentSignature? voiceConsentSignature})
-
ReplicatedVoiceConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- consentAudio → String?
-
Recorded consent verifying ownership of the voice, as base64-encoded
16-bit signed little-endian WAV data with a 24kHz sampling rate.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voiceConsentSignature → VoiceConsentSignature?
-
Signature of a previously verified consent audio, used instead of
consentAudio to reduce latency.
final
- voiceSampleAudio → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited