ToolCall class

A server-side tool call embedded in a model part.

Annotations
  • @JsonSerializable.new(includeIfNull: false, fieldRename: FieldRename.snake)

Constructors

ToolCall({String? id, ToolType? toolType, Map<String, dynamic>? args})
ToolCall.fromJson(Map<String, dynamic> json)
factory

Properties

args Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolType ToolType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited